@@ -8,11 +8,9 @@
 #
 # Copyright (c) 2009-2014 Broad Institute
 # All rights reserved.
-
 """omexml.py read and write OME xml
 
 """
-
 from __future__ import absolute_import, unicode_literals
 
 import xml.etree.ElementTree
@@ -33,6 +31,10 @@ logger = logging.getLogger(__file__)
 import re
 import uuid
 
+version_info = (1, 1, 0)
+__version__ = '.'.join(str(c) for c in version_info)
+
+
 def xsd_now():
     '''Return the current time in xsd:dateTime format'''
     return datetime.datetime.now().isoformat()
@@ -43,7 +45,7 @@ DEFAULT_NOW = xsd_now()
 #
 NS_BINARY_FILE = "http://www.openmicroscopy.org/Schemas/BinaryFile/2013-06"
 NS_ORIGINAL_METADATA = "openmicroscopy.org/OriginalMetadata"
-NS_DEFAULT = "http://www.openmicroscopy.org/Schemas/{ns_key}/2013-06"
+NS_DEFAULT = "http://www.openmicroscopy.org/Schemas/{ns_key}/2016-06"
 NS_RE = r"http://www.openmicroscopy.org/Schemas/(?P<ns_key>.*)/[0-9/-]"
 
 default_xml = """<?xml version="1.0" encoding="UTF-8"?>
@@ -72,8 +74,7 @@ https://docs.openmicroscopy.org/latest/ome-model/ome-tiff/ -->
             </Channel>
         </Pixels>
     </Image>
-  <StructuredAnnotations xmlns="{ns_sa_default}s"/>
-</OME>""".format(ns_ome_default=NS_DEFAULT.format(ns_key='ome'), ns_sa_default=NS_DEFAULT.format(ns_key='sa'))
+</OME>"""
 
 #
 # These are the OME-XML pixel types - not all supported by subimager
@@ -85,10 +86,16 @@ PT_UINT8 = "uint8"
 PT_UINT16 = "uint16"
 PT_UINT32 = "uint32"
 PT_FLOAT = "float"
-PT_BIT = "bit"
 PT_DOUBLE = "double"
 PT_COMPLEX = "complex"
 PT_DOUBLECOMPLEX = "double-complex"
+PT_BIT = "bit"
+
+VALID_DATATYPES = (
+    PT_INT8, PT_INT16, PT_INT32, PT_UINT8, PT_UINT16, PT_UINT32,
+    PT_FLOAT, PT_DOUBLE, PT_COMPLEX, PT_DOUBLECOMPLEX, PT_BIT
+)
+
 #
 # The allowed dimension types
 #
@@ -336,16 +343,41 @@ class OMEXML(object):
         if self.ns['ome'] is None:
             raise Exception("Error: String not in OME-XML format")
 
+    @staticmethod
+    def _indent(elem, width=4, level=0):
+        """
+        Automatically indent XML for improved readability
+        Based on code by Erick M. Sprengel @ https://stackoverflow.com/a/33956544
+
+        Args:
+            elem: root
+            width (int, optional): Number of spaces for each indent level. Defaults to 4.
+            level (int, optional): Initial indent level. Defaults to 0.
+        """
+        indent = " " * width
+        i = "\n%s" % (indent * level)
+        if len(elem):
+            if not elem.text or not elem.text.strip():
+                elem.text = i + indent
+            if not elem.tail or not elem.tail.strip():
+                elem.tail = i
+            for e in elem:
+                OMEXML._indent(e, width, level + 1)
+            if not elem.tail or not elem.tail.strip():
+                elem.tail = i
+        else:
+            if level and (not elem.tail or not elem.tail.strip()):
+                elem.tail = i
+
     def __str__(self):
-        #
         # need to register the ome namespace because BioFormats expects
         # that namespace to be the default or to be explicitly named "ome"
-        #
         for ns_key in ["ome", "sa", "spw"]:
             ns = self.ns.get(ns_key) or NS_DEFAULT.format(ns_key=ns_key)
             ElementTree.register_namespace(ns_key, ns)
         ElementTree.register_namespace("om", NS_ORIGINAL_METADATA)
         result = StringIO()
+        OMEXML._indent(self.root_node)
         ElementTree.ElementTree(self.root_node).write(result,
                                                       encoding=uenc,
                                                       method="xml")
@@ -400,7 +432,6 @@ class OMEXML(object):
     def plates(self):
         return self.PlatesDucktype(self.root_node)
 
-    @property
     def structured_annotations(self):
         '''Return the structured annotations container
 
@@ -726,6 +757,15 @@ class OMEXML(object):
             '''
             return self.node.get("Type")
 
+        def set_PixelType(self, value):
+            if value not in VALID_DATATYPES:
+                raise ValueError(
+                    "Invalid pixel type '%s'. "
+                    "Pixel type must be one of the following options: %s" % (value, VALID_DATATYPES))
+            self.node.set("Type", value)
+        
+        PixelType = property(get_PixelType, set_PixelType)
+
         def get_PhysicalSizeXUnit(self):
             '''The unit of length of a pixel in X direction.'''
             return self.node.get("PhysicalSizeXUnit")
@@ -768,10 +808,6 @@ class OMEXML(object):
             self.node.set("PhysicalSizeZ", str(value))
         PhysicalSizeZ = property(get_PhysicalSizeZ, set_PhysicalSizeZ)
 
-        def set_PixelType(self, value):
-            self.node.set("Type", value)
-        PixelType = property(get_PixelType, set_PixelType)
-
         def get_SizeX(self):
             '''The dimensions of the image in the X direction in pixels'''
             return get_int_attr(self.node, "SizeX")
